Recursion
-----------

**Recursion** is when a method calls itself. The AP CSA exam usually has about 4-6 recursion problems.  You only need to know how to trace recursive methods (figure out what they return or print).  You will *not* be asked to write a recursive method on the exam.

.. toctree::
   :maxdepth: 3

   topic-10-1-recursion-day1.rst
   topic-10-1-recursion-day2.rst
   topic-10-1-recursion-challenge.rst


